@@ -1,6 +1,6 @@
 //
 // srecord - manipulate eprom load files
-// Copyright (C) 1998, 1999, 2001-2008, 2010, 2013 Peter Miller
+// Copyright (C) 1998, 1999, 2001-2008, 2010, 2013, 2014 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -85,7 +85,7 @@ main(int argc, char **argv)
             {
                 std::cerr << "the line length " << line_length << " is invalid"
                     << std::endl;
-                exit(1);
+                exit(EXIT_FAILURE);
             }
             break;
 
@@ -104,7 +104,7 @@ main(int argc, char **argv)
             {
                 std::cerr << "the block size " << output_block_size
                     << " is invalid" << std::endl;
-                exit(1);
+                exit(EXIT_FAILURE);
             }
             break;
 
@@ -118,7 +118,7 @@ main(int argc, char **argv)
             {
                 std::cerr << "the address length " << address_length
                     << " is invalid" << std::endl;
-                exit(1);
+                exit(EXIT_FAILURE);
             }
             break;
 
@@ -166,13 +166,20 @@ main(int argc, char **argv)
         case srec_cat_arglex3::token_header:
             if (cmdline.token_next() != srecord::arglex::token_string)
             {
-                std::cerr << "the header option requires a string argument"
+                std::cerr << "the -header option requires a string argument"
                     << std::endl;
-                exit(1);
+                exit(EXIT_FAILURE);
             }
             header = cmdline.value_string();
             header_set = true;
+
+            //
+            // The users may use %nn on the command line, but we store
+            // a byte 0xnn in the header.  The motivation or this a use
+            // case that wanted to insert a trailing NUL character.
+            //
             header = srecord::string_url_decode(header);
+
             srecord::output_file::enable_header(true);
             break;
 
@@ -181,7 +188,7 @@ main(int argc, char **argv)
             {
                 std::cerr << "too many -execution-start-address options "
                     "specified" << std::endl;
-                exit(1);
+                exit(EXIT_FAILURE);
             }
             cmdline.token_next();
             execution_start_address =
@@ -231,7 +238,7 @@ main(int argc, char **argv)
         {
             std::cerr << "output block size " << output_block_size
                 << " was rejected by " << outfile->format_name() << std::endl;
-            exit(1);
+            exit(EXIT_FAILURE);
         }
     }
 
@@ -247,8 +254,18 @@ main(int argc, char **argv)
     //
     srecord::memory m;
     if (header_set)
+    {
+        // Only the first header is used, even if you have N input
+        // files.  Being set before reading any of the input files, the
+        // command line takes precedence.
         m.set_header(header);
-    m.reader(infile, true);
+    }
+    m.reader
+    (
+        infile,
+        cmdline.get_redundant_bytes(),
+        cmdline.get_contradictory_bytes()
+    );
     if (execution_start_address_set)
         m.set_execution_start_address(execution_start_address);
 
@@ -262,7 +279,7 @@ main(int argc, char **argv)
     //
     // success
     //
-    return 0;
+    return EXIT_SUCCESS;
 }
 
 
