@@ -1,6 +1,6 @@
 //
 // srecord - Manipulate EPROM load files
-// Copyright (C) 2009-2011 Peter Miller
+// Copyright (C) 2009-2011, 2013 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU Lesser General Public License as published by
@@ -16,6 +16,7 @@
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 //
 
+#include <srecord/arglex/tool.h>
 #include <srecord/input/file/mif.h>
 #include <srecord/record.h>
 
@@ -464,11 +465,11 @@ srecord::input_file_mif::get_file_format_name(void)
 }
 
 
-const char *
-srecord::input_file_mif::format_option_name(void)
+int
+srecord::input_file_mif::format_option_number(void)
     const
 {
-    return "-Memory_Initialization_File";
+    return arglex_tool::token_memory_initialization_file;
 }
 
 
