@@ -1,20 +1,19 @@
 //
 // srecord - manipulate eprom load files
-// Copyright (C) 1998-2000, 2002, 2003, 2005-2008, 2010, 2011 Peter Miller
+// Copyright (C) 1998-2000, 2002, 2003, 2005-2008, 2010, 2011, 2013 Peter Miller
 //
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation; either version 3 of the License, or
-// (at your option) any later version.
+// This program is free software; you can redistribute it and/or modify it
+// under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation; either version 3 of the License, or (at your
+// option) any later version.
 //
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU Lesser General Public License for more details.
+// This program is distributed in the hope that it will be useful, but WITHOUT
+// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+// License for more details.
 //
 // You should have received a copy of the GNU Lesser General Public License
-// along with this program. If not, see
-// <http://www.gnu.org/licenses/>.
+// along with this program. If not, see <http://www.gnu.org/licenses/>.
 //
 
 #ifndef LIB_INPUT_FILE_MOTOROLA_H
@@ -59,7 +58,7 @@ protected:
     void command_line(arglex_tool *cmdln);
 
     // See base class for documentation.
-    const char *format_option_name(void) const;
+    int format_option_number(void) const;
 
 private:
     /**
@@ -139,3 +138,4 @@ private:
 };
 
 #endif // LIB_INPUT_FILE_MOTOROLA_H
+// vim: set ts=8 sw=4 et :
