@@ -1,24 +1,24 @@
 //
 // srecord - manipulate eprom load files
-// Copyright (C) 2003, 2006-2008, 2010, 2011 Peter Miller
+// Copyright (C) 2003, 2006-2008, 2010, 2011, 2013 Peter Miller
 //
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation; either version 3 of the License, or
-// (at your option) any later version.
+// This program is free software; you can redistribute it and/or modify it
+// under the terms of the GNU Lesser General Public License as published by
+// the Free Software Foundation; either version 3 of the License, or (at your
+// option) any later version.
 //
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU Lesser General Public License for more details.
+// This program is distributed in the hope that it will be useful, but WITHOUT
+// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+// License for more details.
 //
 // You should have received a copy of the GNU Lesser General Public License
-// along with this program. If not, see
-// <http://www.gnu.org/licenses/>.
+// along with this program. If not, see <http://www.gnu.org/licenses/>.
 //
 
 #include <cctype>
 
+#include <srecord/arglex/tool.h>
 #include <srecord/input/file/spectrum.h>
 #include <srecord/record.h>
 
@@ -185,11 +185,11 @@ srecord::input_file_spectrum::get_file_format_name ()
 }
 
 
-const char *
-srecord::input_file_spectrum::format_option_name(void)
+int
+srecord::input_file_spectrum::format_option_number(void)
     const
 {
-    return "-SPEctrum";
+    return arglex_tool::token_spectrum;
 }
 
 
