@@ -1,6 +1,6 @@
 //
 // srecord - Manipulate EPROM load files
-// Copyright (C) 2009-2011 Peter Miller
+// Copyright (C) 2009-2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU Lesser General Public License as published by
@@ -74,6 +74,12 @@ protected:
       */
     virtual const char *get_algorithm_name() const = 0;
 
+    /**
+      * The get_minimum_alignment method is used to obtain the minium
+      * require dbyte alignment.  Returns 0 if irrelevant.
+      */
+    virtual unsigned get_minimum_alignment(void) const;
+
 private:
     /**
       * The naked instance variable is used to remember whether or not
