@@ -1,6 +1,6 @@
 //
 // srecord - manipulate eprom load files
-// Copyright (C) 2003, 2006-2008, 2010 Peter Miller
+// Copyright (C) 2003, 2006-2008, 2010, 2011 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU Lesser General Public License as published by
@@ -181,3 +181,11 @@ srecord::output_file_formatted_binary::format_name()
 {
     return "Formatted-Binary";
 }
+
+
+bool
+srecord::output_file_formatted_binary::is_binary(void)
+    const
+{
+    return true;
+}
