@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #       srecord - manipulate eprom load files
-#       Copyright (C) 2000, 2003, 2006-2008 Peter Miller
+#       Copyright (C) 2000, 2003, 2006-2008, 2013 Peter Miller
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -18,13 +18,9 @@
 #       <http://www.gnu.org/licenses/>.
 #
 
-TEST_SUBJECT="tekext format"
+TEST_SUBJECT="tekext format, write"
 . test_prelude
 
-# --------------------------------------------------------------------------
-#
-# Test writing this format
-#
 cat > test.in << 'fubar'
 S111000048656C6C6F2C20576F726C64210A7B
 S9030000FC
@@ -32,8 +28,8 @@ fubar
 if test $? -ne 0; then no_result; fi
 
 cat > test.ok << 'fubar'
-%256D980000006B48656C6C6F2C20576F726C64210A
-%0982A80000006B
+%2A6DE80000006B48656C6C6F2C20576F726C64210A
+%0E82F80000006B
 fubar
 if test $? -ne 0; then no_result; fi
 
@@ -43,33 +39,9 @@ if test $? -ne 0; then cat LOG; fail; fi
 diff test.ok test.out
 if test $? -ne 0; then fail; fi
 
-
-# --------------------------------------------------------------------------
-#
-# Test writing this format
-#
-cat > test.in << 'fubar'
-%15621810000000202020202020
-%09819800000000
-fubar
-if test $? -ne 0; then no_result; fi
-
-cat > test.ok << 'fubar'
-S00600004844521B
-S30B1000000020202020202024
-S5030001FB
-S9030000FC
-fubar
-if test $? -ne 0; then no_result; fi
-
-srec_cat test.in -tekext -o test.out -header HDR
-if test $? -ne 0; then fail; fi
-
-diff test.ok test.out
-if test $? -ne 0; then fail; fi
-
 #
 # The things tested here, worked.
 # No other guarantees are made.
 #
 pass
+# vim: set ts=8 sw=4 et :
