@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #       srecord - manipulate eprom load files
-#       Copyright (C) 2003, 2006-2008 Peter Miller
+#       Copyright (C) 2003, 2006-2008, 2013 Peter Miller
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
@@ -70,7 +70,7 @@ cat > test.ok << 'fubar'
 fubar
 if test $? -ne 0; then no_result; fi
 
-srec_cat test.in -o test.out -vmem 8 -ll 20
+srec_cat test.in -o test.out -vmem 8 -line-leng 20
 if test $? -ne 0; then fail; fi
 
 diff test.ok test.out
@@ -144,3 +144,6 @@ if test $? -ne 0; then fail; fi
 # No other guarantees are made.
 #
 pass
+
+
+// vim: set ts=8 sw=4 et :
